"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultCookies = defaultCookies;
exports.SessionStore = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _classPrivateFieldGet4 = _interopRequireDefault(require("@babel/runtime/helpers/classPrivateFieldGet"));

var _classPrivateFieldSet2 = _interopRequireDefault(require("@babel/runtime/helpers/classPrivateFieldSet"));

var _cookie = require("cookie");

function _classPrivateMethodInitSpec(obj, privateSet) { _checkPrivateRedeclaration(obj, privateSet); privateSet.add(obj); }

function _classPrivateFieldInitSpec(obj, privateMap, value) { _checkPrivateRedeclaration(obj, privateMap); privateMap.set(obj, value); }

function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }

function _classPrivateMethodGet(receiver, privateSet, fn) { if (!privateSet.has(receiver)) { throw new TypeError("attempted to get private field on non-instance"); } return fn; }

function defaultCookies(useSecureCookies) {
  const cookiePrefix = useSecureCookies ? "__Secure-" : "";
  return {
    sessionToken: {
      name: `${cookiePrefix}next-auth.session-token`,
      options: {
        httpOnly: true,
        sameSite: "lax",
        path: "/",
        secure: useSecureCookies
      }
    },
    callbackUrl: {
      name: `${cookiePrefix}next-auth.callback-url`,
      options: {
        sameSite: "lax",
        path: "/",
        secure: useSecureCookies
      }
    },
    csrfToken: {
      name: `${useSecureCookies ? "__Host-" : ""}next-auth.csrf-token`,
      options: {
        httpOnly: true,
        sameSite: "lax",
        path: "/",
        secure: useSecureCookies
      }
    },
    pkceCodeVerifier: {
      name: `${cookiePrefix}next-auth.pkce.code_verifier`,
      options: {
        httpOnly: true,
        sameSite: "lax",
        path: "/",
        secure: useSecureCookies
      }
    }
  };
}

var _chunks = new WeakMap();

var _option = new WeakMap();

var _logger = new WeakMap();

var _ALLOWED_COOKIE_SIZE = new WeakMap();

var _CHUNK_SIZE = new WeakMap();

var _chunk = new WeakSet();

class SessionStore {
  constructor(option, req, logger) {
    var _req$headers, _req$headers$Authoriz;

    _classPrivateMethodInitSpec(this, _chunk);

    _classPrivateFieldInitSpec(this, _chunks, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldInitSpec(this, _option, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldInitSpec(this, _logger, {
      writable: true,
      value: void 0
    });

    _classPrivateFieldInitSpec(this, _ALLOWED_COOKIE_SIZE, {
      writable: true,
      value: 4096
    });

    _classPrivateFieldInitSpec(this, _CHUNK_SIZE, {
      writable: true,
      value: void 0
    });

    (0, _defineProperty2.default)(this, "type", "cookie");
    (0, _classPrivateFieldSet2.default)(this, _logger, logger);
    (0, _classPrivateFieldSet2.default)(this, _option, option);
    (0, _classPrivateFieldSet2.default)(this, _CHUNK_SIZE, (0, _classPrivateFieldGet4.default)(this, _ALLOWED_COOKIE_SIZE) - (0, _cookie.serialize)(`${option.name}.0`, "", option.options).length);
    if (!req) return;
    const chunks = [];

    for (const name in req.cookies) {
      if (name.startsWith(option.name)) {
        chunks.push(req.cookies[name]);
      }
    }

    if (chunks.length) (0, _classPrivateFieldSet2.default)(this, _chunks, chunks);
    const bearer = (_req$headers = req.headers) === null || _req$headers === void 0 ? void 0 : (_req$headers$Authoriz = _req$headers.Authorization) === null || _req$headers$Authoriz === void 0 ? void 0 : _req$headers$Authoriz.replace("Bearer ", "");

    if (bearer) {
      logger.debug("Found session token in request headers.", {});
      this.type = "bearer";
      (0, _classPrivateFieldSet2.default)(this, _chunks, [bearer]);
    }
  }

  get value() {
    var _classPrivateFieldGet2;

    return (_classPrivateFieldGet2 = (0, _classPrivateFieldGet4.default)(this, _chunks)) === null || _classPrivateFieldGet2 === void 0 ? void 0 : _classPrivateFieldGet2.join("");
  }

  chunk(value, cookieOptions) {
    const cookies = {};
    const cleaned = this.clean();

    if (cleaned.length === 1) {
      cookies.unchunked = cleaned[0];
    } else {
      cleaned.forEach((cookie, i) => {
        cookies[i] = cookie;
      });
    }

    const chunkedCookies = _classPrivateMethodGet(this, _chunk, _chunk2).call(this, {
      name: (0, _classPrivateFieldGet4.default)(this, _option).name,
      value,
      options: cookieOptions
    });

    (0, _classPrivateFieldSet2.default)(this, _chunks, chunkedCookies.map(c => c.value));

    if (chunkedCookies.length === 1) {
      cookies.unchunked = chunkedCookies[0];
    } else {
      chunkedCookies.forEach((chunk, i) => {
        cookies[i] = chunk;
      });
    }

    return Object.values(cookies);
  }

  clean() {
    var _classPrivateFieldGet3;

    if (!(0, _classPrivateFieldGet4.default)(this, _chunks)) return [];
    const clean = {
      name: (0, _classPrivateFieldGet4.default)(this, _option).name,
      value: "",
      options: { ...(0, _classPrivateFieldGet4.default)(this, _option).options,
        maxAge: 0
      }
    };
    if ((0, _classPrivateFieldGet4.default)(this, _chunks).length === 1) return [clean];
    return (_classPrivateFieldGet3 = (0, _classPrivateFieldGet4.default)(this, _chunks)) === null || _classPrivateFieldGet3 === void 0 ? void 0 : _classPrivateFieldGet3.map((_, i) => ({ ...clean,
      name: `${(0, _classPrivateFieldGet4.default)(this, _option).name}.${i}`
    }));
  }

}

exports.SessionStore = SessionStore;

function _chunk2(cookie) {
  const chunkCount = Math.ceil(cookie.value.length / (0, _classPrivateFieldGet4.default)(this, _CHUNK_SIZE));
  if (chunkCount === 1) return [cookie];
  (0, _classPrivateFieldGet4.default)(this, _logger).debug(`Cookie value is bigger than ${(0, _classPrivateFieldGet4.default)(this, _ALLOWED_COOKIE_SIZE)} bytes, needs chunking...`, {
    cookieSize: cookie.value.length,
    chunkCount
  });
  const cookies = [];

  for (let i = 0; i < chunkCount; i++) {
    const chunk = cookie.value.substr(i * (0, _classPrivateFieldGet4.default)(this, _CHUNK_SIZE), (0, _classPrivateFieldGet4.default)(this, _CHUNK_SIZE));
    cookies.push({ ...cookie,
      name: `${cookie.name}.${i}`,
      value: chunk
    });
  }

  return cookies;
}